pub struct R(/* private fields */);Expand description
Register PAUSE_FRAMES_TXED reader
Implementations
Sourceimpl R
impl R
Sourcepub fn count_pause(&self) -> COUNT_PAUSE_R
pub fn count_pause(&self) -> COUNT_PAUSE_R
Bits 0:15 - Transmitted pause frames - a 16 bit register counting the number of pause frames transmitted. Only pause frames triggered by the register interface or through the external pause pins are counted as pause frames. Pause frames received through the external FIFO interface are counted in the frames transmitted counter.
Methods from Deref<Target = R<PAUSE_FRAMES_TXED_SPEC>>