R

Struct R 

pub struct R(/* private fields */);
Register ACQUIRE reader

Implementations

Source

impl R

pub fn p(&self) -> P_R

Bit 0 - User/privileged access control: ‘0’: user mode. ‘1’: privileged mode. This field is set with the user/privileged access control of the access that successfully acquired the lock.

pub fn ns(&self) -> NS_R

Bit 1 - Secure/non-secure access control: ‘0’: secure. ‘1’: non-secure. This field is set with the secure/non-secure access control of the access that successfully acquired the lock.

pub fn pc(&self) -> PC_R

Bits 4:7 - This field specifies the protection context that successfully acquired the lock.

pub fn ms(&self) -> MS_R

Bits 8:11 - This field specifies the bus master identifier that successfully acquired the lock.

pub fn success(&self) -> SUCCESS_R

Bit 31 - Specifies if the lock is successfully acquired or not (reading the ACQUIRE register can have affect on SUCCESS and LOCK_STATUS.ACQUIRED): ‘0’: Not successfully acquired; i.e. the lock was already acquired by another read transaction and not released. The P, NS, PC and MS fields reflect the access attributes of the transaction that previously successfully acuired the lock; the fields are NOT affected by the current access. ‘1’: Successfully acquired. The P, NS, PC and MS fields reflect the access attributes of the current access. Note that this field is NOT SW writable. A lock is released by writing to the associated RELEASE register (irrespective of the write value).

Methods from Deref<Target = R<ACQUIRE_SPEC>>

pub fn bits(&self) -> REG::Ux

Reads raw bits from register.