W

Struct W 

pub struct W(/* private fields */);
Register ERROR_CTL writer

Implementations

Source

impl W

pub fn ch_idx(&mut self) -> CH_IDX_W<'_, 0>

Bits 0:4 - Specifies the channel index of the channel to which HW injected channel transmitter errors applies.

pub fn tx_sync_error(&mut self) -> TX_SYNC_ERROR_W<'_, 16>

Bit 16 - The synchronization field is changed from 0x55 to 0x00. At the receiver, this should result in INTR.RX_HEADER_SYNC_ERROR activation.

pub fn tx_sync_stop_error(&mut self) -> TX_SYNC_STOP_ERROR_W<'_, 17>

Bit 17 - The synchronization field STOP bits are inverted to ‘0’. At the receiver, this should result in INTR.RX_HEADER_SYNC_ERROR or INTR.RX_HEADER_FRAME_ERROR activation.

pub fn tx_parity_error(&mut self) -> TX_PARITY_ERROR_W<'_, 18>

Bit 18 - In LIN mode, the PID parity bit P[1] is inverted from !(ID[5] ^ ID[4] ^ ID[3] ^ ID[1]) to (ID[5] ^ ID[4] ^ ID[3] ^ ID[1]). At the receiver, this should result in INTR.RX_HEADER_PARITY_ERROR activation. In UART mode, a data field’s parity bit is inverted.

pub fn tx_pid_stop_error(&mut self) -> TX_PID_STOP_ERROR_W<'_, 19>

Bit 19 - The PID field STOP bits are inverted to ‘0’. At the receiver, this should result in INTR.RX_HEADER_FRAME_ERROR activation.

pub fn tx_data_stop_error(&mut self) -> TX_DATA_STOP_ERROR_W<'_, 21>

Bit 21 - The data field STOP bits are inverted to ‘0’. At the receiver, this should result in INTR.RX_RESPONSE_FRAME_ERROR activation. Note: Used in UART mode.

pub fn tx_checksum_error(&mut self) -> TX_CHECKSUM_ERROR_W<'_, 22>

Bit 22 - The checksum field is inverted. At the receiver, this should result in INTR.RX_RESPONSE_CHECKSUM_ERROR activation.

pub fn tx_checksum_stop_error(&mut self) -> TX_CHECKSUM_STOP_ERROR_W<'_, 23>

Bit 23 - The checksum field STOP bits are inverted to ‘0’. At the receiver, this should result in INTR.RX_RESPONSE_FRAME_ERROR activation.

pub fn enabled(&mut self) -> ENABLED_W<'_, 31>

Bit 31 - Error injection enable: ‘0’: Disabled. ‘1’: Enabled.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Methods from Deref<Target = W<ERROR_CTL_SPEC>>

pub unsafe fn bits(&mut self, bits: REG::Ux) -> &mut Self

Writes raw bits to the register.

Safety

Read datasheet or reference manual to find what values are allowed to pass.