pub struct R(/* private fields */);Expand description
Register UART_FLOW_CTRL reader
Implementations
Sourceimpl R
impl R
Sourcepub fn trigger_level(&self) -> TRIGGER_LEVEL_R
pub fn trigger_level(&self) -> TRIGGER_LEVEL_R
Bits 0:7 - Trigger level. When the receiver FIFO has less entries than the amount of this field, a Ready To Send (RTS) output signal is activated. By setting this field to ‘0’, flow control is effectively disabled (may be useful for debug purposes).
Sourcepub fn rts_polarity(&self) -> RTS_POLARITY_R
pub fn rts_polarity(&self) -> RTS_POLARITY_R
Bit 16 - Polarity of the RTS output signal: ‘0’: RTS is active low; ‘1’: RTS is active high; During SCB reset (Hibernate system power mode), RTS output signal is ‘1’. This represents an inactive state assuming an active low polarity.
Sourcepub fn cts_polarity(&self) -> CTS_POLARITY_R
pub fn cts_polarity(&self) -> CTS_POLARITY_R
Bit 24 - Polarity of the CTS input signal ‘0’: CTS is active low ; ‘1’: CTS is active high;
Sourcepub fn cts_enabled(&self) -> CTS_ENABLED_R
pub fn cts_enabled(&self) -> CTS_ENABLED_R
Bit 25 - Enable use of CTS input signal by the UART transmitter: ‘0’: Disabled. The UART transmitter ignores the CTS input signal and transmits when a data frame is available for transmission in the TX FIFO or the TX shift register. ‘1’: Enabled. The UART transmitter uses CTS input signal to qualify the transmission of data. It transmits when CTS input signal is active and a data frame is available for transmission in the TX FIFO or the TX shift register. If UART_CTRL.LOOPBACK is ‘1’, the CTS input signal is driven by the RTS output signal locally in SCB (both signals are subjected to signal polarity changes are indicated by RTS_POLARITY and CTS_POLARITY).