pub struct W(/* private fields */);Expand description
Register CMD_RESP_CTRL writer
Implementations
Sourceimpl W
impl W
Sourcepub fn base_rd_addr(&mut self) -> BASE_RD_ADDR_W<'_, 0>
pub fn base_rd_addr(&mut self) -> BASE_RD_ADDR_W<'_, 0>
Bits 0:8 - I2C/SPI read base address for CMD_RESP mode. At the start of a read transfer this BASE_RD_ADDR is copied to CMD_RESP_STATUS.CURR_RD_ADDR. This field should not be modified during ongoing bus transfers.
Sourcepub fn base_wr_addr(&mut self) -> BASE_WR_ADDR_W<'_, 16>
pub fn base_wr_addr(&mut self) -> BASE_WR_ADDR_W<'_, 16>
Bits 16:24 - I2C/SPI write base address for CMD_RESP mode. At the start of a write transfer this BASE_WR_ADDR is copied to CMD_RESP_STATUS.CURR_WR_ADDR. This field should not be modified during ongoing bus transfers.
Methods from Deref<Target = W<CMD_RESP_CTRL_SPEC>>