W

Struct W 

pub struct W(/* private fields */);
Register UART_TX_CTRL writer

Implementations

Source

impl W

pub fn stop_bits(&mut self) -> STOP_BITS_W<'_, 0>

Bits 0:2 - Stop bits. STOP_BITS + 1 is the duration of the stop period in terms of halve bit periods. Valid range is [1, 7]; i.e. a stop period should last at least one bit period.

pub fn parity(&mut self) -> PARITY_W<'_, 4>

Bit 4 - Parity bit. When ‘0’, the transmitter generates an even parity. When ‘1’, the transmitter generates an odd parity. Only applicable in standard UART and SmartCard submodes.

pub fn parity_enabled(&mut self) -> PARITY_ENABLED_W<'_, 5>

Bit 5 - Parity generation enabled (‘1’) or not (‘0’). Only applicable in standard UART submodes. In SmartCard submode, parity generation is always enabled through hardware. In IrDA submode, parity generation is always disabled through hardware

pub fn retry_on_nack(&mut self) -> RETRY_ON_NACK_W<'_, 8>

Bit 8 - When ‘1’, a data frame is retransmitted when a negative acknowledgement is received. Only applicable to the SmartCard submode.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Methods from Deref<Target = W<UART_TX_CTRL_SPEC>>

pub unsafe fn bits(&mut self, bits: REG::Ux) -> &mut Self

Writes raw bits to the register.

Safety

Read datasheet or reference manual to find what values are allowed to pass.