MODE_A

Enum MODE_A 

#[repr(u8)]
pub enum MODE_A { UART_STD = 0, UART_SMARTCARD = 1, UART_IRDA = 2, }
N/A

Value on reset: 3

Variants



UART_STD = 0

0: Standard UART submode.



UART_SMARTCARD = 1

1: SmartCard (ISO7816) submode. Support for negative acknowledgement (NACK) on the receiver side and retransmission on the transmitter side.



UART_IRDA = 2

2: Infrared Data Association (IrDA) submode. Return to Zero modulation scheme. In this mode, the oversampling factor should be 16, that is OVS should be set to 15.