pub struct R(/* private fields */);Expand description
Register ALIGNMENT_ERRORS reader
Implementations
Sourceimpl R
impl R
Sourcepub fn count_alignment_error(&self) -> COUNT_ALIGNMENT_ERROR_R
pub fn count_alignment_error(&self) -> COUNT_ALIGNMENT_ERROR_R
Bits 0:9 - Alignment errors - a 10 bit register counting frames that are not an integral number of bytes long and have bad CRC when their length is truncated to an integral number of bytes and are between 64 and 1518 bytes in length (1536 if bit 8 set in network configuration register, 10,240 bytes if bit 3 is set in the network configuration register). This register is also incremented if a symbol error is detected and the frame is of valid length and does not have an integral number of bytes.
Methods from Deref<Target = R<ALIGNMENT_ERRORS_SPEC>>