pub struct R(/* private fields */);Expand description
Register RX_CTRL reader
Implementations
Sourceimpl R
impl R
Sourcepub fn data_width(&self) -> DATA_WIDTH_R
pub fn data_width(&self) -> DATA_WIDTH_R
Bits 0:4 - Dataframe width. DATA_WIDTH + 1 is the expected amount of bits in received data frame. This number does not include start, parity and stop bits. For UART mode, the valid range is [3, 8]. For SPI, the valid range is [3, 31]. For I2C the only valid value is 7. In EZ mode (for both SPI and I2C), the only valid value is 7.
Sourcepub fn msb_first(&self) -> MSB_FIRST_R
pub fn msb_first(&self) -> MSB_FIRST_R
Bit 8 - Least significant bit first (‘0’) or most significant bit first (‘1’). For I2C, this field should be ‘1’.
Sourcepub fn median(&self) -> MEDIAN_R
pub fn median(&self) -> MEDIAN_R
Bit 9 - Median filter. When ‘1’, a digital 3 taps median filter is performed on input interface lines. This filter should reduce the susceptibility to errors. However, its requires higher oversampling values. For UART IrDA submode, this field should always be ‘1’.
Methods from Deref<Target = R<RX_CTRL_SPEC>>